==> jc-1.4.0.tar.gz: java/util/logging/SocketHandler.h <==
// public class java.util.logging.SocketHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class 556a577414f749c9 java_util_logging_SocketHandler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_SocketHandler_H_
#define _JC_java_util_logging_SocketHandler_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_SocketHandler$sub_refs	_jc_java_util_logging_SocketHandler$sub_refs;
typedef struct _jc_java_util_logging_SocketHandler$sub_nonrefs	_jc_java_util_logging_SocketHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_SocketHandler$refs	_jc_java_util_logging_SocketHandler$refs;
typedef struct _jc_java_util_logging_SocketHandler$nonrefs	_jc_java_util_logging_SocketHandler$nonrefs;
typedef struct _jc_java_util_logging_SocketHandler$object	_jc_java_util_logging_SocketHandler$object;

typedef struct _jc_java_util_logging_SocketHandler$fields_struct	_jc_java_util_logging_SocketHandler$fields_struct;
typedef const struct _jc_java_util_logging_SocketHandler$vmethods	_jc_java_util_logging_SocketHandler$vmethods;
typedef const struct _jc_java_util_logging_SocketHandler$vtable	_jc_java_util_logging_SocketHandler$vtable;
typedef const struct _jc_java_util_logging_SocketHandler$vtype	_jc_java_util_logging_SocketHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_SocketHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24XMLFormatter;
};
extern _jc_java_util_logging_SocketHandler$fields_struct _jc_java_util_logging_SocketHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_SocketHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *);
extern void _jc_java_util_logging_SocketHandler$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern void _jc_java_util_logging_SocketHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_util_logging_LogRecord$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_SocketHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_SocketHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_io_OutputStream$object *_jc_java_util_logging_SocketHandler$method$createSocket$ed92ff672000d36c(_jc_env *, struct _jc_java_lang_String$object *, jint);
extern jint _jc_java_util_logging_SocketHandler$method$getPortNumber$66a7d7fbfc5345d1(_jc_env *);

// Virtual methods structure
struct _jc_java_util_logging_SocketHandler$vmethods {
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_util_logging_LogRecord$object *);
};

// Vtable
struct _jc_java_util_logging_SocketHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_SocketHandler$vmethods	java_util_logging_SocketHandler;
};

// Vtype
struct _jc_java_util_logging_SocketHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_SocketHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_SocketHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_SocketHandler$refs {
    _jc_java_util_logging_SocketHandler$sub_refs	java_util_logging_SocketHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_SocketHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_SocketHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_SocketHandler$sub_nonrefs	java_util_logging_SocketHandler;
};

// Object instance structure
struct _jc_java_util_logging_SocketHandler$object {
	_jc_java_util_logging_SocketHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_SocketHandler$vtype	*vtype;
	_jc_java_util_logging_SocketHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_SocketHandler$vtype _jc_java_util_logging_SocketHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_SocketHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_SocketHandler$class_object;

#endif	/* _JC_java_util_logging_SocketHandler_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/SocketHandler.h <==
// public class java.util.logging.SocketHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class 556a577414f749c9 java_util_logging_SocketHandler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_SocketHandler_H_
#define _JC_java_util_logging_SocketHandler_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_SocketHandler$sub_refs	_jc_java_util_logging_SocketHandler$sub_refs;
typedef struct _jc_java_util_logging_SocketHandler$sub_nonrefs	_jc_java_util_logging_SocketHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_SocketHandler$refs	_jc_java_util_logging_SocketHandler$refs;
typedef struct _jc_java_util_logging_SocketHandler$nonrefs	_jc_java_util_logging_SocketHandler$nonrefs;
typedef struct _jc_java_util_logging_SocketHandler$object	_jc_java_util_logging_SocketHandler$object;

typedef struct _jc_java_util_logging_SocketHandler$fields_struct	_jc_java_util_logging_SocketHandler$fields_struct;
typedef const struct _jc_java_util_logging_SocketHandler$vmethods	_jc_java_util_logging_SocketHandler$vmethods;
typedef const struct _jc_java_util_logging_SocketHandler$vtable	_jc_java_util_logging_SocketHandler$vtable;
typedef const struct _jc_java_util_logging_SocketHandler$vtype	_jc_java_util_logging_SocketHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_SocketHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24XMLFormatter;
};
extern _jc_java_util_logging_SocketHandler$fields_struct _jc_java_util_logging_SocketHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_SocketHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_SocketHandler$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_logging_SocketHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_SocketHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_SocketHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_java_util_logging_SocketHandler$method$createSocket$ed92ff672000d36c(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java_util_logging_SocketHandler$method$getPortNumber$66a7d7fbfc5345d1(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_SocketHandler$vmethods {
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_SocketHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_SocketHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_SocketHandler$vmethods	java_util_logging_SocketHandler;
};

// Vtype
struct _jc_java_util_logging_SocketHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_SocketHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_SocketHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_SocketHandler$refs {
    _jc_java_util_logging_SocketHandler$sub_refs	java_util_logging_SocketHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_SocketHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_SocketHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_SocketHandler$sub_nonrefs	java_util_logging_SocketHandler;
};

// Object instance structure
struct _jc_java_util_logging_SocketHandler$object {
	_jc_java_util_logging_SocketHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_SocketHandler$vtype	*vtype;
	_jc_java_util_logging_SocketHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_SocketHandler$vtype _jc_java_util_logging_SocketHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_SocketHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_SocketHandler$class_object;

#endif	/* _JC_java_util_logging_SocketHandler_H_ */
